import axios from "axios";

export default {
  fetchCustomerData({ commit, getters }) {
    let query;
    if (getters.getColumn == "all") {
      query = "q=" + getters.getSearch;
    } else if (getters.getColumn) {
      query = getters.getColumn + "_like=" + getters.getSearch;
    }

    let pageLimit = `&_page=${getters.getOptions.page}&_limit=${getters.getOptions.itemsPerPage}`;

    let sort = getters.getOptions.sortDesc[0] ? "desc" : "asc";

    let sortBy = `&_sort=${getters.getOptions.sortBy}&_order=${sort}`;

    commit("setLoading", true);
    axios
      .get(`http://localhost:3000/customers?${query}${pageLimit}${sortBy}`)
      .then((response) => {
        commit("setTotalCustomers", response.headers["x-total-count"]);
        commit("setCustomerList", response.data);
        commit("setLoading", false);
      })
      .catch((e) => {
        console.log(e);
      });
  },

  searchData({ commit, dispatch }, { data, column }) {
    commit("setPageNumber");
    dispatch("setSearch", data);
    dispatch("setColumn", column);
    dispatch("fetchCustomerData");
  },

  setOptions({ commit, dispatch }, data) {
    commit("setOptions", data);
    dispatch("fetchCustomerData");
  },

  setSearch({ commit }, data) {
    commit("setSearch", data);
  },

  setColumn({ commit }, data) {
    commit("setColumn", data);
  },

  setSelected({ commit }, data) {
    commit("setSelected", data);
  },

  closeDialog({ commit }) {
    commit("setDialog", false);
  },

  deleteCustomer({ dispatch, commit }, idList) {
    confirm("Are you sure you want to delete this item?") &&
      idList.forEach((id) => {
        commit("setLoading", true);
        axios
          .delete(`http://localhost:3000/customers/${id}`)
          .then(() => {
            dispatch("fetchCustomerData");
            commit("setLoading", false);
          })
          .catch((e) => {
            console.log(e);
          });
      });
  },

  deleteMultiCustomer({ dispatch }, items) {
    const itemList = [];
    items.forEach((item) => {
      itemList.push(item.id);
    });
    dispatch("deleteCustomer", itemList);
    dispatch("setSelected", []);
  },

  saveCustomer({ getters, dispatch, commit }) {
    const postConfig = {
      method: "post",
      url: `http://localhost:3000/customers/`,
      data: getters.editedItem,
    };

    const putConfig = {
      method: "put",
      url: `http://localhost:3000/customers/${getters.editedItem.id}`,
      data: getters.editedItem,
    };
    commit("setLoading", true);
    axios(!getters.editedItem.id ? postConfig : putConfig).then(() => {
      dispatch("fetchCustomerData");
      commit("setLoading", false);
    });
    dispatch("closeDialog");
  },

  editCustomer({ commit }, item) {
    commit("setEditedItem", Object.assign({}, item));
    commit("setDialog", true);
  },
};
